@@ -3,6 +3,7 @@
 aembit_raw_output_chain_name=aembit_raw_output_chain
 aembit_nat_output_chain_name=aembit_nat_output_chain
 aembit_nat_prerouting_chain_name=aembit_nat_prerouting_chain
+aembit_filter_input_chain_name=aembit_filter_input_chain
 
 aembit_group_id=$(id --group aembit_agent_proxy)
 agent_proxy_port=38080
@@ -13,7 +14,7 @@ azure_platform_resources_ip=168.63.129.16
 update-alternatives --set iptables /usr/sbin/iptables-legacy
 update-alternatives --set ip6tables /usr/sbin/ip6tables-legacy
 
-custom_chains=("raw,OUTPUT,$aembit_raw_output_chain_name" "nat,OUTPUT,$aembit_nat_output_chain_name" "nat,PREROUTING,$aembit_nat_prerouting_chain_name")
+custom_chains=("raw,OUTPUT,$aembit_raw_output_chain_name" "nat,OUTPUT,$aembit_nat_output_chain_name" "nat,PREROUTING,$aembit_nat_prerouting_chain_name" "filter,INPUT,$aembit_filter_input_chain_name")
 
 for custom_chain in "${custom_chains[@]}"; do
     # Split to table, buildit chain and custom chain name
